@@ -23,10 +23,6 @@
 
 #include <QApplication>
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2( oxygen-qt, Oxygen::StylePlugin )
-#endif
-
 namespace Oxygen
 {
 
